justbases._config module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »

# justbases._config module

Configuration of the justbytes package.

class `justbases._config.` `BaseConfig`(use_prefix=False, use_subscript=True)

  Bases: `object`

  Whether and how to show the base.

class `justbases._config.` `BasesConfig`

  Bases: `object`

  Configuration class for any bases things.

  `DISPLAY_CONFIG` = DisplayConfig(show_approx_str=True, base_config=BaseConfig(use_prefix=False, use_subscript=True), digits_config=DigitsConfig(separator=~, use_caps=False, use_letters=True), strip_config-StripConfig(strip=False, strip_exact=False, strip_whole=True))
  classmethod `set_display_config`(config)

    Set configuration for superficial aspects of display.

    Parameters: | config (DisplayConfig) – a configuration object

class `justbases._config.` `DigitsConfig`(separator='~', use_caps=False, use_letters=True)

  Bases: `object`

  How to display digits.

class `justbases._config.` `DisplayConfig`(show_approx_str=True, base_config=BaseConfig(use_prefix=False, use_subscript=True), digits_config=DigitsConfig(separator=~, use_caps=False, use_letters=True), strip_config=StripConfig(strip=False, strip_exact=False, strip_whole=True))

  Bases: `object`

  Superficial aspects of display.

class `justbases._config.` `StripConfig`(strip=False, strip_exact=False, strip_whole=True)

  Bases: `object`

  Stripping trailing zeros.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »
- justbases package »